<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Dashboard\Application\Repository;

use Core\Dashboard\Domain\Model\Dashboard;
use Core\Dashboard\Domain\Model\NewDashboard;

interface WriteDashboardRepositoryInterface
{
    /**
     * Add a dashboard.
     *
     * @param NewDashboard $newDashboard
     *
     * @throws \Throwable
     *
     * @return int
     */
    public function add(NewDashboard $newDashboard): int;

    /**
     * Delete a dashboard.
     *
     * @param int $dashboardId
     *
     * @throws \Throwable
     */
    public function delete(int $dashboardId): void;

    /**
     * Update a dashboard.
     *
     * @param Dashboard $dashboard
     *
     * @throws \Throwable
     */
    public function update(Dashboard $dashboard): void;

    /**
     * @param int $dashboardId
     * @param int $thumbnailId
     *
     * @throws \Throwable
     */
    public function addThumbnailRelation(int $dashboardId, int $thumbnailId): void;
}
